@@ -65,11 +65,11 @@
  * cmml_open: Takes a filename and opens it as read-only. Then checks
  * whether it is an XML file satisfying the CMML specification with
  * the xml directive and the cmml tag. It returns a CMML object.
- * If you're working on an already opened file, use cmml_open_stdio
+ * If you're working on an already opened file, use cmml_new
  * instead.
  */
 CMML * 
-cmml_open (char *XMLfilename)
+cmml_open (const char *XMLfilename)
 {
   FILE * file;
   CMML_Context * context;
