@@ -80,7 +80,7 @@ typedef enum _CMML_Time_Type {
 
 /**
  * CMML_Time: a time specification in CMML: either seconds or utc
- * time; keeps the orininal time string for reuse, too
+ * time; keeps the original time string for reuse, too
  */
 typedef struct {
   char *tstr;          /**< copy of original time string for reuse in printing */
@@ -90,14 +90,13 @@ typedef struct {
     CMML_UTC * utc;    /**< actual time in utc */
     double sec;        /**< actual time in seconds */
   } t;
-} CMML_Time ;
+} CMML_Time;
 
 
 /**
  * CMML_List: A doubly linked list
  */
 typedef struct _CMML_List CMML_List;
-
 /**
  * USE THE DEFINED TYPE CMML_List FOR THIS!
  *
@@ -170,7 +169,7 @@ typedef struct {
   CMML_Time * start_time; /**< insertion time in annodex bitstream */
   CMML_Time * end_time;   /**< end time of this logical  bitstream */
   char *title;            /**< comment on the import bitstream */
-  CMML_List * param;      /**< list of optional further nam-value
+  CMML_List * param;      /**< list of optional further name-value
 			     metadata for the import bitstreams */
 } CMML_ImportElement;
 
@@ -190,7 +189,7 @@ typedef struct {
 
 /**
  * CMML_MetaElement: a struct to keep the details of the meta tag in
- * either a head or an clip
+ * either a head or a clip
  */
 typedef struct {
   char *id;      /**< id attribute of meta element */
@@ -238,7 +237,7 @@ typedef struct {
 
 
 /**
- * CMML_Clip: an clip element as presented in the CMML document.
+ * CMML_Clip: a clip element as presented in the CMML document.
  */
 typedef struct {
   char *clip_id;         /**< id attribute of clip */
@@ -308,7 +307,7 @@ typedef struct {
  * - general processing feedback (CMML_OK, CMML_EOF)
  * - fatal processing feedback (these errors render the CMML file useless)
  * - tolerable processing errors (these lead to ignoring certain tags)
- * The user may select to 
+ * The user may select to ignore sloppy errors
  */
 typedef enum _CMML_Error_Type {
   /* general processing feedback */
@@ -396,13 +395,13 @@ typedef int (*CMMLReadClip) (CMML *cmml, const CMML_Clip *clip,
  * cmml_open: Takes a filename and opens it as read-only. Then checks
  * whether it is an XML file satisfying the CMML specification with
  * the xml directive and the cmml tag. It returns a CMML object.  If
- * you're working on an already opened FILE*, use cmml_open_stdio instead.
+ * you're working on an already opened FILE*, use cmml_new instead.
  *
  * \param XMLfilename a CMML file to open
  *
  * \returns a CMML* handle
  */
-CMML * cmml_open (char *XMLfilename);
+CMML * cmml_open (const char *XMLfilename);
 
 /**
  * cmml_attach_parser: Takes a FILE pointer to an already-opened CMML
@@ -625,7 +624,7 @@ double cmml_skip_to_offset (CMML *cmml, const char * offset);
  *
  * \returns a CMML preamble
  */
-CMML_Preamble * cmml_preamble_new (char *encoding, char *id, char *lang, char *dir, char *granulerate);
+CMML_Preamble * cmml_preamble_new (const char *encoding, const char *id, const char *lang, const char *dir, const char *granulerate);
 
 /**
  * cmml_element_new: Create a new CMML_Element.
@@ -653,7 +652,7 @@ CMML_Head    * cmml_head_new    (void);
 /**
  * cmml_clip_new: Create a new CMML_Anchr.
  *
- * \param start_time the start time at which to create an clip
+ * \param start_time the start time at which to create a clip
  * \param end_time the end time at which to end the clip
  *
  * \returns a clip element
