@@ -54,7 +54,7 @@
  * cmml_preamble_new: Create a new CMML_Preamble.
  */
 CMML_Preamble * 
-cmml_preamble_new (char *encoding, char *id, char *lang, char *dir, char *granulerate)
+cmml_preamble_new (const char *encoding, const char *id, const char *lang, const char *dir, const char *granulerate)
 {
   CMML_Preamble * p;
   p = (CMML_Preamble *) cmml_malloc(sizeof(CMML_Preamble));
