@@ -159,7 +159,7 @@ fix_npt_str(const char *str)
   return fixed_string;;
 }
 
-/* tstr_fix: INLINE function to parse a sec-string */
+/* cmml_tstr_fix: INLINE function to parse a sec-string */
 /* and fix it, tolerating slighly off secifications of npt and smpte */
 char *
 cmml_tstr_fix (const char * str)
@@ -435,7 +435,7 @@ cmml_time_clone (CMML_Time * t1)
   return t;
 }
 
-/* parse_sec: parse a sec-string of stream, head or clip tag */
+/* cmml_parse_sec: parse a sec-string of stream, head or clip tag */
 /* this parses a name-value pair of npt:xxx, smpte:xxx etc. */
 double
 cmml_sec_parse (const char * str)
@@ -485,7 +485,27 @@ cmml_sec_parse (const char * str)
 
 }
 
-/* parse_utc: parse a utc-string of utc-tag in head or of clips */
+/* creates a time struct from a time spec in seconds */
+CMML_Time *
+cmml_time_new_secs (double seconds)
+{
+  CMML_Time * t = NULL;
+  char *tstr;
+
+  /* memory allocation */
+  tstr = (char *) cmml_malloc (sizeof(char)*32);
+  t = (CMML_Time *) cmml_malloc (sizeof(CMML_Time));
+
+  /* fill fields */
+  cmml_npt_snprint (tstr, 32, seconds);
+  t->tstr = tstr;
+  t->type = CMML_SEC_TIME;
+  t->t.sec = seconds;
+
+  return t;  
+}
+
+/* cmml_parse_utc: parse a utc-string of utc-tag in head or of clips */
 /* this is just parsing the plain utc string YYYYMMDDTHHmmss.hhZ */
 CMML_UTC *
 cmml_utc_parse (const char * s)
@@ -660,14 +680,16 @@ int cmml_npt_snprint (char * buf, int n, double seconds)
 
   hrs = (int) (seconds/3600.0);
   min = (int) ((seconds - ((double)hrs * 3600.0)) / 60.0);
-  sec = seconds - ((double)hrs * 3600.0)- ((double)min * 60.0);
+  sec = fabs(seconds - ((double)hrs * 3600.0)- ((double)min * 60.0));
+
 
   /* XXX: %02.3f workaround */
   if (sec < 10.0) {
-    return sprintf (buf, "%s%2d:%02d:0%2.3f", sign, hrs, min, sec);
+    return sprintf (buf, "%s%d:%0d:0%2.3f", sign, hrs, min, sec);
   } else {
-    return sprintf (buf, "%s%2d:%02d:%02.3f", sign, hrs, min, sec);
+    return sprintf (buf, "%s%d:%02d:%02.3f", sign, hrs, min, sec);
   }
+
 }
 
 /*
