@@ -279,7 +279,7 @@ int main(int argc, char *argv[])
   }
 
   /* write preamble */
-  pre = cmml_preamble_new(encoding, NULL, NULL, NULL);
+  pre = cmml_preamble_new(encoding, NULL, NULL, NULL, NULL);
   cmml_preamble_snprint (buf, BUFSIZE, pre);
   fputs (buf, outfile);
   cmml_preamble_destroy(pre);
